@@ -24,6 +24,7 @@ using namespace std::chrono_literals;
 
 ApplicationListModel::ApplicationListModel(HomeScreen *parent)
     : QAbstractListModel(parent)
+    , m_homeScreen{parent}
     , m_reloadAppsTimer{new QTimer{this}}
 {
     m_reloadAppsTimer->setSingleShot(true);
@@ -112,7 +113,7 @@ void ApplicationListModel::load()
 
     std::sort(toRemove.begin(), toRemove.end());
 
-    // Remove indices first, from end to start to avoid indicies changing
+    // Remove indices first, from end to start to avoid indices changing
     for (int i = toRemove.size() - 1; i >= 0; --i) {
         int ind = toRemove[i];
 
@@ -130,8 +131,8 @@ void ApplicationListModel::load()
 
     // Append new elements
     for (const KService::Ptr &service : toInsert) {
-        FolioApplication::Ptr app = std::make_shared<FolioApplication>(m_homeScreen, service);
-        FolioDelegate::Ptr delegate = std::make_shared<FolioDelegate>(app, m_homeScreen);
+        FolioApplication::Ptr app = std::make_shared<FolioApplication>(service);
+        FolioDelegate::Ptr delegate = std::make_shared<FolioDelegate>(app);
 
         beginInsertRows({}, m_delegates.size(), m_delegates.size());
         m_delegates.append(delegate);
