@@ -13,7 +13,7 @@
 #include <KConfigGroup>
 #include <KSharedConfig>
 
-// applications-blacklistrc
+// .config/plasma-mobile/applications-blacklistrc
 // NOTE: we only write these entries if they are not already defined in the config
 const QMap<QString, QMap<QString, QVariant>> APPLICATIONS_BLACKLIST_DEFAULT_SETTINGS = {
     {"Applications",
@@ -24,15 +24,22 @@ const QMap<QString, QMap<QString, QVariant>> APPLICATIONS_BLACKLIST_DEFAULT_SETT
        "nvtop,qt5-qdbusviewer,qv4l2,qvidcap,syncmonitorhelper,UserFeedbackConsole,waydroid.com.android.calculator2,waydroid.com.android.camera2,"
        "waydroid.com.android.contacts,waydroid.com.android.deskclock,waydroid.com.android.documentsui,waydroid.com.android.gallery3d,"
        "waydroid.com.android.inputmethod.latin,waydroid.com.android.settings,waydroid.org.lineageos.eleven,waydroid.org.lineageos.etar,"
-       "waydroid.org.lineageos.jelly,waydroid.org.lineageos.recorder,wordview"}}}};
+       "waydroid.org.lineageos.jelly,waydroid.org.lineageos.recorder,wordview,org.kde.drkonqi.coredump.gui"}}}};
 
-// kdeglobals
-// NOTE: we only write these entries if they are not already defined in the config
+// .config/plasma-mobile/kdeglobals - non-immutable settings:
 const QMap<QString, QMap<QString, QVariant>> KDEGLOBALS_DEFAULT_SETTINGS = {{"General", {{"BrowserApplication", "angelfish"}}}};
 
+// .config/plasma-mobile/kdeglobals - immutable settings:
 const QMap<QString, QMap<QString, QVariant>> KDEGLOBALS_SETTINGS = {{"KDE", {{"LookAndFeelPackage", "org.kde.breeze.mobile"}}}};
 
-// plasma-mobile/kwinrc
+// .config/plasma-mobile/kwinrc - non-immutable settings:
+const QMap<QString, QMap<QString, QVariant>> KWINRC_DEFAULT_SETTINGS = {
+    {"Wayland",
+     {
+         {"InputMethod", "/usr/share/applications/com.github.maliit.keyboard.desktop"} // ensure maliit is our default vkbd
+     }}};
+
+// .config/plasma-mobile/kwinrc - immutable settings:
 QMap<QString, QMap<QString, QVariant>> getKwinrcSettings(KSharedConfig::Ptr m_mobileConfig)
 {
     auto group = KConfigGroup{m_mobileConfig, QStringLiteral("General")};
@@ -40,6 +47,7 @@ QMap<QString, QMap<QString, QVariant>> getKwinrcSettings(KSharedConfig::Ptr m_mo
 
     return {{"Windows",
              {
+                 {"BorderlessMaximizedWindows", !convergenceModeEnabled}, // turn off window decorations when not in convergence mode
                  {"Placement", convergenceModeEnabled ? "Centered" : "Maximizing"}, // maximize all windows by default if we aren't in convergence mode
                  {"InteractiveWindowMoveEnabled", convergenceModeEnabled} // only allow window moving in convergence mode
              }},
@@ -53,7 +61,6 @@ QMap<QString, QMap<QString, QVariant>> getKwinrcSettings(KSharedConfig::Ptr m_mo
              }},
             {"Wayland",
              {
-                 {"InputMethod", "/usr/share/applications/com.github.maliit.keyboard.desktop"}, // ensure maliit is our vkbd
                  {"VirtualKeyboardEnabled", true} // enable vkbd
              }},
             {"org.kde.kdecoration2",
@@ -72,5 +79,5 @@ QMap<QString, QMap<QString, QVariant>> getKwinrcSettings(KSharedConfig::Ptr m_mo
 const QList<QString> KWIN_EFFECTS = {"blur", "mobiletaskswitcher", "screenedge"};
 const QList<QString> KWIN_SCRIPTS = {"convergentwindows"};
 
-// plasma-mobile/ksmserver
+// .config/plasma-mobile/ksmserver - immutable settings:
 const QMap<QString, QMap<QString, QVariant>> KSMSERVER_SETTINGS = {{"General", {{"loginMode", "emptySession"}}}};
